Package 'svPkgdown'

Title: 'SciViews::R' - 'pkgdown' Template
Description: This is a private template to style pkgdown sub-sites in https://www.sciviews.org. Please don't use it for another purpose.
Authors: Philippe Grosjean [aut, cre] (ORCID: <https://orcid.org/0000-0002-2694-9471>)
Maintainer: Philippe Grosjean <[email protected]>
License: MIT + file LICENSE
Version: 1.0.1
Built: 2026-05-26 09:04:17 UTC
Source: https://github.com/SciViews/svPkgdown

Help Index


'pkgdown' Template for 'SciViews::R' Packages

Description

This package is used to produce the documentation of R packages on https://www.sciviews.org. Please, do not use it unmodified for other purposes.

Author(s)

Maintainer: Philippe Grosjean [email protected] (ORCID)

See Also

Useful links:


Test function

Description

Test function

Usage

test()

Examples

test()